/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { ContentCreateRequest, Content } from '../definitions/Content';
import { History } from '../definitions/History';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface CreateContentRequest extends HeadersOption, ErrorStrategyOption {
    status?: string;
    expand?: string;
    body: ContentCreateRequest;
}
export interface CreateContentResponseOK extends Content {
}
export interface CreateContentResponseError extends CommonError {
}
export interface GetContentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * the content type to return. Default value: page. Valid values: page, blogpost.
     */
    type?: 'page' | 'blogpost';
    /**
     * the space key to find content under.
     */
    spaceKey?: string;
    /**
     * the title of the page to find. Required for page type.
     */
    title?: string;
    /**
     * list of statuses the content to be found is in. Defaults to current is not specified. If set to 'any', content in 'current' and 'trashed' status will be fetched. Does not support 'historical' status for now.
     */
    status?: string;
    /**
     * the posting day of the blog post. Required for blogpost type. Format: yyyy-mm-dd. Example: 2013-02-13
     */
    postingDay?: string;
    /**
     * a comma separated list of properties to expand on the content. Default value: history,space,version.
     */
    expand?: string;
    /**
     * the start point of the collection to return
     */
    start?: number;
    /**
     * the limit of the number of items to return, this may be restricted by fixed system limits
     */
    limit?: number;
}
export interface GetContentsResponseOK {
    start?: number;
    limit?: number;
    size?: number;
    results?: Content[];
}
export interface GetContentsResponseError extends CommonError {
}
export interface UpdateContentRequest extends HeadersOption, ErrorStrategyOption {
    contentId: string;
    /**
     * the existing status of the content to be updated.
     */
    status?: string;
    conflictPolicy?: string;
    body: ContentCreateRequest;
}
export interface UpdateContentResponseOK extends Content {
}
export interface UpdateContentResponseError extends CommonError {
}
export interface GetContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Content ID.
     */
    id: string;
    /**
     * list of Content statuses to filter results on. Default value: [current]
     */
    status?: string;
    version?: number;
    /**
     * A comma separated list of properties to expand on the content. Default value: history,space,version We can also specify some extensions such as extensions.inlineProperties (for getting inline comment-specific properties) or extensions.resolution for the resolution status of each comment in the results
     */
    expand?: string;
}
export interface GetContentResponseOK extends Content {
}
export interface GetContentResponseError extends CommonError {
}
export interface DeleteContentRequest extends HeadersOption, ErrorStrategyOption {
    /**
    * Content ID.
    */
    id: string;
    /**
     * the status of the content to be deleted
     */
    status?: string;
}
export declare type DeleteContentResponseOK = undefined;
export interface DeleteContentResponseError extends CommonError {
}
export interface GetContentHistoryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Content ID.
     */
    id: string;
    /**
     * the properties on content history to expand
     */
    expand?: string;
}
export interface GetContentHistoryResponseOK extends History {
}
export interface GetContentHistoryResponseError extends CommonError {
}
//# sourceMappingURL=content.d.ts.map