/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { Content } from '../../definitions/Content';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetChildrenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Content ID.
     */
    id: string;
    /**
     * a comma separated list of properties to expand on the children
     */
    expand?: string;
    /**
     * an int representing the version of the content to retrieve children for
     */
    parentVersion?: number;
    start?: number;
    limit?: number;
}
export interface GetChildrenResponseOK {
    attachment?: {
        start?: number;
        limit?: number;
        size?: number;
        results?: Content[];
    };
    comment?: {
        start?: number;
        limit?: number;
        size?: number;
        results?: Content[];
    };
    page?: {
        start?: number;
        limit?: number;
        size?: number;
        results?: Content[];
    };
}
export interface GetChildrenCommonError extends CommonError {
}
export interface GetChildrenOfTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Content ID.
     */
    id: string;
    type: 'page' | 'comment' | 'attachment';
    /**
     * a comma separated list of properties to expand on the children
     */
    expand?: string;
    /**
     * an int representing the version of the content to retrieve children for
     */
    parentVersion?: number;
    /**
     * (optional, default: 0) the index of the first item within the result set that should be returned
     */
    start?: number;
    /**
     * (optional, default: site limit) how many items should be returned after the start index
     */
    limit?: number;
}
export interface GetChildrenOfTypeResponseOK {
    start?: number;
    limit?: number;
    size?: number;
    results?: Content[];
}
export interface GetChildrenOfTypeCommonError extends CommonError {
}
export interface GetCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Content ID.
     */
    id: string;
    /**
     * a comma separated list of properties to expand on the children. We can also specify some extensions such as extensions.inlineProperties (for getting inline comment-specific properties) or extensions.resolution for the resolution status of each comment in the results
     */
    expand?: string;
    /**
     * an int representing the version of the content to retrieve children for
     */
    parentVersion?: number;
    /**
     * (optional, default: 0) the index of the first item within the result set that should be returned
     */
    start?: number;
    /**
     * (optional, default: site limit) how many items should be returned after the start index
     */
    limit?: number;
    /**
     * (optional, default: "" means all) the location of the comments. Possible values are: "inline", "footer", "resolved". You can define multiple location params. The results will be the comments matched by any location.
     */
    location?: '' | 'inline' | 'footer' | 'resolved';
    /**
     * (optional, default: "") the depth of the comments. Possible values are: "" (ROOT only), "all"
     */
    depth?: '' | 'all';
}
export interface GetCommentsResponseOK {
    start?: number;
    limit?: number;
    size?: number;
    results?: Content[];
}
export interface GetCommentsCommonError extends CommonError {
}
//# sourceMappingURL=child.d.ts.map