/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { Content } from '../definitions/Content';
import { FormattedBody } from '../definitions/FormattedBody';
import { Space } from '../definitions/Space';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetSpacesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * a list of space keys
     */
    spaceKey?: string[];
    /**
     * filter the list of spaces returned by type (global, personal)
     */
    type?: 'global' | 'personal';
    /**
     * filter the list of spaces returned by status (current, archived)
     */
    status?: 'current' | 'archived';
    /**
     * filter the list of spaces returned by label
     */
    label?: string;
    /**
     * filter the list of spaces returned by favourites
     */
    favourite?: boolean;
    /**
     * a comma separated list of properties to expand on the spaces
     */
    expand?: string;
    /**
     * the start point of the collection to return
     */
    start?: number;
    /**
     * the limit of the number of spaces to return, this may be restricted by fixed system limits
     */
    limit?: number;
}
export interface GetSpacesResponseOK {
    start?: number;
    limit?: number;
    size?: number;
    results?: Space[];
}
export interface GetSpacesResponseError extends CommonError {
}
export interface CreateSpaceRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        name: string;
        key: string;
        description: Record<string, FormattedBody>;
    };
}
export interface CreateSpaceResponseOK extends Space {
}
export interface CreateSpaceResponseError extends CommonError {
}
export interface UpdateSpaceRequest extends HeadersOption, ErrorStrategyOption {
    spaceKey: string;
    body: {
        name?: string;
        description?: Record<string, FormattedBody>;
        homepage?: Content;
    };
}
export interface UpdateSpaceResponseOK extends Space {
}
export interface UpdateSpaceResponseError extends CommonError {
}
export interface DeleteSpaceRequest extends HeadersOption, ErrorStrategyOption {
    spaceKey: string;
}
export interface DeleteSpaceResponseOK {
    id?: string;
    links?: {
        status?: string;
    };
}
export interface DeleteSpaceResponseError extends CommonError {
}
//# sourceMappingURL=space.d.ts.map